//*********************************************************
//
// FldLabel:		    Overload the microsoft .net Label to implement 
//                      rep++ Label field control
//
// Author:		        Maher Najah
//
// (c) 2003 by Consyst SQL Inc.
//
//
//*********************************************************
using System;
using System.Collections;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using RepPP;
using RepPP.Toolkit;

namespace RepPP.Toolkit.Window {
	/// <summary>
	/// FldLabel: Create a Label around a rep++ field
	/// </summary>
	public class FldLabel : System.Windows.Forms.Label, FldControlUtil.IFldControl
	{
        /// <summary>Field control utility class</summary>
        protected FldControlUtil                    m_fldControlUtil;
        /// <summary>Text of the label</summary>
		private string                              m_strText;
        /// <summary> Required designer variable</summary>
		private System.ComponentModel.Container     components = null;
        //*********************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //*********************************************************
		public FldLabel()	{
			InitializeComponent();
            m_strText        = null;
            m_fldControlUtil = new FldControlUtil(this, false);
		}

        //*********************************************************	    
        //
        /// <summary>
        /// Dispose:                    Dispose the control
        /// </summary>
        /// <param name="bDisposing">   true if dispose, false if GC </param>
        //
        //*********************************************************	    
        protected override void Dispose(bool bDisposing) {
            RepPP.Application   app;

			if (bDisposing) {
                if(components != null) {
                    components.Dispose();
                }
                if (m_fldControlUtil != null) {
                    app = Application;
                    if (app != null) {
                        app.ProgInit  -= new RepPP.ProgInitEventHandler(this.OnProgInit);
                        app.ProgEnd   -= new RepPP.ProgEndEventHandler(this.OnProgEnd);
                        app.FldChange -= new RepPP.FldChangeEventHandler(this.OnFldChange);
                    }
                    m_fldControlUtil.Dispose();
                    m_fldControlUtil = null;
                }
			}
			base.Dispose(bDisposing);
		}

        //********************************************************************************
        //
		/// <summary>
		/// RepPPReInit:        Called when Rep++ is reinitialized in design mode
		/// </summary>
		//
        //********************************************************************************
        public void RepPPReInit() {
            RefreshCtl();
        }

        //********************************************************************************
        //
		/// <summary>
		/// RepPPReset:         Called when Rep++ is reset in design mode
		/// </summary>
		//
        //********************************************************************************
        public void RepPPReset() {
            m_strText = "[" + FieldFullName.GroupName + "." + FieldFullName.FieldName + "]";
        }

        //********************************************************************************
        //
        /// <summary>
        /// TriggerComponentChange:     Trigger the event indicating a component property has changed
        /// </summary>
        //
        //********************************************************************************
        public virtual void TriggerComponentChange() {
            if (m_fldControlUtil != null) {
                m_fldControlUtil.TriggerComponentChange();
                RefreshCtl();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// FieldFullName:              Full name of the field attached to the label
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Editor(typeof(FldControlUtil.FldControlEditor), typeof(System.Drawing.Design.UITypeEditor))]
        [Browsable(true)]
        [Bindable(true)]
        [Category("Data")]
        [Description("Full name of the field attached to the label")]
		public FldFullName FieldFullName {
		    get {
		        return(m_fldControlUtil.FieldFullName);
		    }
		    set {
		        m_fldControlUtil.FieldFullName = value;
                RefreshCtl();
		    }
		}

        //********************************************************************************
        //
        /// <summary>
        /// Application:            Gets the Rep++ application
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
		public RepPP.Application Application {
		    get {
		        return(m_fldControlUtil.Application);
		    }
		}

        //*********************************************************
        //
        /// <summary>
        /// FieldName:      Get and set the field name
        /// </summary>
        //
        //*********************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public string FieldName {
            get {
                return(FieldFullName.FieldName);
            }
            set {
                FieldFullName.FieldName = value;
                RefreshCtl();
            }
        }

        //*********************************************************
        //
        /// <summary>
        /// GroupName:      Get and set the group name
        /// </summary>
        //
        //*********************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public string GroupName {
            get {
                return(FieldFullName.GroupName);
            }
            set {
                FieldFullName.GroupName = value;
                RefreshCtl();
            }
        }

        //*********************************************************
        //
        /// <summary>
        /// Field:              Get the attached field
        /// </summary>
        //
        //*********************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
		public Field Field {
		    get {
		        return(m_fldControlUtil.Field);
		    }
		    set {
		        m_fldControlUtil.Field = value;
                RefreshCtl();
		    }
		}

        //*********************************************************
        //
        /// <summary>
        /// ResetState:         Reset the state of the control
        /// </summary>
        //
        //*********************************************************
        private void ResetState() {
            Field   fld;

            if (!DesignMode) {
                fld = m_fldControlUtil.Field;
                if (fld != null) {
                    this.Visible = (fld.IsVisible);
                }
            }
        }

        //*********************************************************
        //
        /// <summary>
        /// RefreshCtl:         Refresh the control
        /// </summary>
        //
        //*********************************************************
        private void RefreshCtl() {
            ResetState();
            m_strText = null;
            Invalidate();
        }

        //*********************************************************
        //
        /// <summary>
        /// OnProgInit:           Handle the application initialized event
        /// </summary>
        /// <param name="sender"> Sender object   </param>
        /// <param name="e">      Event arguments </param>
        //
        //*********************************************************
        private void OnProgInit(object sender, RepPP.ApplicationEventArgs e) {
            RefreshCtl();
        }

        //*********************************************************
        //
        /// <summary>
        /// OnProgEnd:            Handle the application end event
        /// </summary>
        /// <param name="sender"> Sender object   </param>
        /// <param name="e">      Event arguments </param>
        //
        //*********************************************************
        private void OnProgEnd(object sender, RepPP.ApplicationEventArgs e) {
            RefreshCtl();
        }

        //*********************************************************
        //
        /// <summary>
        /// OnFldChange:          Handle the field change event
        /// </summary>
        /// <param name="sender"> Sender object   </param>
        /// <param name="e">      Event arguments </param>
        //
        //*********************************************************
        private void OnFldChange(object sender, RepPP.FieldGenEventArgs e) {
            Field   fld;

            fld = (m_fldControlUtil != null) ? m_fldControlUtil.Field : null;
            if (fld != null && fld == e.Field) {
                switch(e.FldEvent) {
                case FldEvent.sdFldPromptChg:
                    m_strText = null;
                    Invalidate();
                    break;
                case FldEvent.sdFldStateChg:
                    ResetState();
                    break;
                }
            }
        }

        //*********************************************************
        //
        /// <summary>
        /// OnCreateControl:    Called when the control is created
        /// </summary>
        //
        //*********************************************************
        protected override void OnCreateControl() {
            RepPP.Application   app;

            app = Application;
            if (app != null) {
                ResetState();
                if (!DesignMode) {
                    app.ProgInit  += new RepPP.ProgInitEventHandler(this.OnProgInit);
                    app.ProgEnd   += new RepPP.ProgEndEventHandler(this.OnProgEnd);
                    app.FldChange += new RepPP.FldChangeEventHandler(this.OnFldChange);
                }
            }
            base.OnCreateControl();
        }

        //*********************************************************
        //
        /// <summary>
        /// Text:               Text of the control
        /// </summary>
        //
        //*********************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public override string Text {
            get {
                string          strRetVal;
                RepPP.Field     fld;

                if (m_strText == null) {
                    fld = m_fldControlUtil.Field;
                    if (fld == null) {
                        m_strText = "[? " + m_fldControlUtil.FieldFullName.GroupName + "." + m_fldControlUtil.FieldFullName.FieldName + " ?]";
                    } else {
                        m_strText = GetTextDisplayedFromField(fld);
                    }
                }
                strRetVal = m_strText;
                return(strRetVal);
            }
            set {
                // Do nothing
            }
        }

        //*********************************************************
        //
        /// <summary>
        /// GetTextDisplayed:   Get Control Text to display 
        ///                     from field
        /// </summary>
        //
        //*********************************************************
        protected virtual string GetTextDisplayedFromField(RepPP.Field fld) {
            return(fld.Prompt);
        }

		#region Component Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			components = new System.ComponentModel.Container();
		}
		#endregion
	} // class SCFldLabel
} // namesapce
