using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Xml;
using sdfwwebcsnet;
using System.Web;
using System.IO;
using RepPP.Toolkit;

namespace RepPP.VSNetWizard.Web
{
	/// <summary>
	/// WebGeneratorForVB: Code generator for VB
	/// </summary>
	internal class GeneratorForVB : GeneratorBase
	{

        //******************************************************************
        //
        /// <summary>
        /// ctor:                                   Class constructor
        /// </summary>
        /// <param name="vsApp">                    Visual studio application</param>
        /// <param name="app">                      Rep++ application object</param>
        /// <param name="strHTMLTemplateDir">       HTML Template directory</param>
        /// <param name="strHTMLMetaTemplateFile">  HTML metatemplate file</param>
        /// <param name="arrLanguages">             Selected languages</param>
        /// <param name="eGenTypedInst">            Generated typed instances flag</param>
        //
        //******************************************************************
		public GeneratorForVB(EnvDTE.DTE                    vsApp,
                              RepPP.IApplication            app,
                              string                        strHTMLTemplateDir,
                              string                        strHTMLMetaTemplateFile,
                              ArrayList                     arrLanguages,
                              Utility.GenTypedInstParam     genTypedInstParam) : base (vsApp,
                                                                                       app,
                                                                                       strHTMLTemplateDir,
                                                                                       strHTMLMetaTemplateFile,
                                                                                       arrLanguages,
                                                                                       genTypedInstParam) {
        }

        //*********************************************************     
        //
        /// <summary>
        /// CreateProjectP:                 Create a new visual studio project
        /// </summary>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strPrjFullName">   Project full name</param>
        /// <returns>
        /// The created project
        /// </returns>
        //  
        //*********************************************************     
        protected override EnvDTE.Project CreateProjectP(ref string strPrjName, ref string strPrjFullName)
        {
            return(Utility.CreateWebProject(m_vsApp,
                                            ProgramLanguageE.sdVisualBasic,
                                            ref strPrjName,
                                            ref strPrjFullName));
        }

        //*********************************************************     
        //
        /// <summary>
        /// AddDispatchClassv:          Add the dispatch class to the project 
        /// </summary>
        /// <param name="strPrjName">   Project name</param>
        //
        //*********************************************************     
        protected override void AddDispatchClassV(string strPrjName)
        {
            EnvDTE.Project      project;
            StreamWriter        writer;
            string              strFileName;
            string              strText;

            project     = GetProjectP(strPrjName);
            strFileName = System.IO.Path.GetDirectoryName(project.FullName);
            strFileName = System.IO.Path.Combine(strFileName, "SCUserDispatch.vb");
            strText     = "' <summary>\r\n" +
                          "' SCUserDispatch: The dispatch class\r\n" +
                          "' </summary>\r\n" +
                          "Public Class SCUserDispatch\r\n" +
                          "    Inherits sdfwwebcsnet.SCDispatchASPNet\r\n" +
                          "    Public Sub New()\r\n" +
                          "        MyBase.New()\r\n" +
                          "    End Sub\r\n" +
                          "End Class";
            using (writer = Utility.CreateTextFile(strFileName, Utility.ReplaceFileModeE.sdReplaceWithoutAsk)) {
                writer.Write(strText);
            }
            project.ProjectItems.AddFromFile(strFileName);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenCardTypedInstanceV:          Generate card typed instance 
        /// </summary>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strCardName">      Card name</param>
        //
        //*********************************************************     
        protected override void GenCardTypedInstanceV(string strPrjName, string strCardName) {
            Utility.GenCardTypedInstance(Utility.GetProject(m_vsApp, strPrjName),
                                         m_genTypedInstParam.m_strCardInstClassPrefix,
                                         m_genTypedInstParam.m_strGroupInstClassPrefix,
                                         m_genTypedInstParam.m_strGroupInstPropPrefix,
                                         m_genTypedInstParam.m_strFieldPropPrefix,
                                         m_genTypedInstParam.m_strNamespace,
                                         m_genTypedInstParam.m_strRootNamespace,
                                         m_genTypedInstParam.m_strCardInstBaseClass,
                                         m_genTypedInstParam.m_strGroupInstBaseClass,
                                         new TypedInstanceGenForVB(),
                                         (m_genTypedInstParam.m_eGenType == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter),
                                         m_app.Cards[strCardName],
                                         Utility.ReplaceFileModeE.sdReplaceWithoutAsk,
                                         String.Empty,
                                         true);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenGroupTypedInstanceV:         Genearte group typed instance 
        /// </summary>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strGroupName">     Group name</param>
        //
        //*********************************************************     
        protected override void GenGroupTypedInstanceV(string strPrjName, string strGroupName) {
            Utility.GenGroupTypedInstance(Utility.GetProject(m_vsApp, strPrjName),
                                          m_genTypedInstParam.m_strCardInstClassPrefix,
                                          m_genTypedInstParam.m_strGroupInstClassPrefix,
                                          m_genTypedInstParam.m_strGroupInstPropPrefix,
                                          m_genTypedInstParam.m_strFieldPropPrefix,
                                          m_genTypedInstParam.m_strNamespace,
                                          m_genTypedInstParam.m_strRootNamespace,
                                          m_genTypedInstParam.m_strGroupInstBaseClass,
                                          new TypedInstanceGenForVB(),
                                          (m_genTypedInstParam.m_eGenType == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter),
                                          m_app.Groups[strGroupName],
                                          Utility.ReplaceFileModeE.sdReplaceWithoutAsk,
                                          String.Empty);
        }

        //*********************************************************     
        //
        /// <summary>
        /// CodeFileExtension:         Get the extension of the code file
        /// </summary>
        //
        //*********************************************************     
        protected override string CodeFileExtension {
            get {
                return(".vb");
            }
        }
	} // class GeneratorForVB
} // namaspace
