//*********************************************************
//
// frmStepRepConnect:    Step form to enter rep++ connection parameters
//
// Author:		         Maher Najah
//
// (c) 2004 by Consyst SQL Inc.
//
//
//*********************************************************
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.IO;
using System.Resources;
using System.Windows.Forms;
using System.Xml;
using RepPP.VSNetWizard;

namespace RepPP.VSNetWizard
{
	/// <summary>
	/// frmStepRepConnect: Enter the rep++ connection parameters
	/// </summary>
	internal class frmStepRepConnect : frmStepBase {
        protected System.Windows.Forms.Label        lblConnection;
        protected System.Windows.Forms.TextBox      txtConnection;
        protected System.Windows.Forms.TextBox      txtSystem;
        protected System.Windows.Forms.Label        lblSystem;
        protected System.Windows.Forms.TextBox      txtProgram;
        protected System.Windows.Forms.Label        lblProgram;
        protected System.Windows.Forms.TextBox      txtUser;
        protected System.Windows.Forms.Label        lblUser;
        protected System.Windows.Forms.Label        lblLanguage;
        protected System.Windows.Forms.TextBox      txtPassword;
        protected System.Windows.Forms.Label        lblPassword;
        protected System.Windows.Forms.Button       butConnWizard;
        protected System.Windows.Forms.ComboBox     cboLanguage;
		private System.ComponentModel.Container     components = null;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmStepRepConnect() {
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        /// <param name="frmMain">      Main form</param>
        //
        //******************************************************************
		public frmStepRepConnect(frmMainBase frmMain) : base(frmMain) {
            EnvDTE.Project      prjCurrent;
            EnvDTE.ProjectItem  prjItem;
            string              strFileName;
            ResXResourceSet     resxSet;
            string              strLang;

			InitializeComponent();
            cboLanguage.Items.AddRange(new object[] {"Default", "French", "English", "Spanish", "German", "Italian"});
            cboLanguage.SelectedIndex = 0;
            prjCurrent                = m_frmMain.CurrentProject;
            if (prjCurrent != null) {
                prjItem = Utility.FindProjectItem(m_frmMain.CurrentProject, "RepPPInfo.resx");
                if (prjItem != null) {
                    strFileName                 = prjItem.get_FileNames(0);
                    resxSet                     = new ResXResourceSet(strFileName);
                    txtProgram.Text             = resxSet.GetString("PrgName",  true);
                    txtSystem.Text              = resxSet.GetString("SysName",  true);
                    txtConnection.Text          = resxSet.GetString("ConnName", true);
                    txtUser.Text                = resxSet.GetString("UserName", true);
                    txtPassword.Text            = resxSet.GetString("Pwd",      true);
                    strLang                     = resxSet.GetString("Language", true);
                    if (strLang != String.Empty) {
                        cboLanguage.SelectedIndex = int.Parse(strLang);
                    }
                }
            }
		}

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                if (components != null) {
                    components.Dispose();
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// InitV:                    Initialize the step
        /// </summary>
        //
        //******************************************************************
        public override void InitV() {
            base.InitV();
        }

        //******************************************************************
        //
        /// <summary>
        /// ValidateB:                    Validate the step
        /// </summary>
        /// <returns>
        /// True:   Valid
        /// False:  Not Valid
        /// </returns>
        //
        //******************************************************************
        public override bool ValidateB() {
            return(txtConnection.Text != String.Empty &&
                   txtSystem.Text     != String.Empty &&
                   txtProgram.Text    != String.Empty &&
                   txtUser.Text       != String.Empty &&
                   cboLanguage.SelectedIndex > -1);
        }

        //******************************************************************
        //
        /// <summary>
        /// Connection:             Connection name
        /// </summary>
        //
        //******************************************************************
        public string Connection
        {
            get {
                return(txtConnection.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// User:             User name
        /// </summary>
        //
        //******************************************************************
        public string User {
            get {
                return(txtUser.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// Password:             Password name
        /// </summary>
        //
        //******************************************************************
        public string Password {
            get {
                return(txtPassword.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// System:             System name
        /// </summary>
        //
        //******************************************************************
        public string System {
            get {
                return(txtSystem.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// Program:             Program name
        /// </summary>
        //
        //******************************************************************
        public string Program {
            get {
                return(txtProgram.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// Language:             Language used for the connection 
        /// </summary>
        //
        //******************************************************************
        public int Language {
            get {
                return(cboLanguage.SelectedIndex);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// OnButConnWizardClick:       Handle click event on the button connection wizard
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnButConnWizardClick(object sender, System.EventArgs e) {
            string              strConnection = String.Empty;
            string              strUser       = String.Empty;
            string              strPassword   = String.Empty;
            string              strSystem     = String.Empty;
            string              strProgram    = String.Empty;
            RepPP.Application   app           = null;

            try {
                app = RepPP.Application.GetApplication();
                if (app == null) {
                    app = RepPP.Application.Create();
                }
                RepPP.ConnWizard.ShowDialog(ref strConnection,
                                            ref strUser,
                                            ref strPassword,
                                            ref strSystem,
                                            ref strProgram,
                                            2,
                                            m_frmMain.Handle.ToInt32());
                if (strConnection != String.Empty) {
                    txtConnection.Text = strConnection;
                    txtUser.Text       = strUser;
                    txtPassword.Text   = strPassword;
                    txtProgram.Text    = strProgram;
                    txtSystem.Text     = strSystem;
                }
            } catch (System.Exception ex) {
                MessageBox.Show(ex.ToString());
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// OnConnectionParamChanged:       Handle changed event on the one of the 
        ///                                 connection parameters
        /// </summary>
        /// <param name="sender">           Sender</param>
        /// <param name="e">                Event arguments</param>
        //
        //******************************************************************
        private void OnConnectionParamChanged(object sender, System.EventArgs e) {
            m_frmMain.NextButton.Enabled = ValidateB();
        }
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.lblConnection = new System.Windows.Forms.Label();
            this.txtConnection = new System.Windows.Forms.TextBox();
            this.txtSystem = new System.Windows.Forms.TextBox();
            this.lblSystem = new System.Windows.Forms.Label();
            this.txtProgram = new System.Windows.Forms.TextBox();
            this.lblProgram = new System.Windows.Forms.Label();
            this.txtUser = new System.Windows.Forms.TextBox();
            this.lblUser = new System.Windows.Forms.Label();
            this.lblLanguage = new System.Windows.Forms.Label();
            this.butConnWizard = new System.Windows.Forms.Button();
            this.txtPassword = new System.Windows.Forms.TextBox();
            this.lblPassword = new System.Windows.Forms.Label();
            this.cboLanguage = new System.Windows.Forms.ComboBox();
            this.pnlStep.SuspendLayout();
            this.SuspendLayout();
            // 
            // pnlStep
            // 
            this.pnlStep.Controls.Add(this.cboLanguage);
            this.pnlStep.Controls.Add(this.txtPassword);
            this.pnlStep.Controls.Add(this.lblPassword);
            this.pnlStep.Controls.Add(this.butConnWizard);
            this.pnlStep.Controls.Add(this.txtUser);
            this.pnlStep.Controls.Add(this.txtProgram);
            this.pnlStep.Controls.Add(this.txtSystem);
            this.pnlStep.Controls.Add(this.txtConnection);
            this.pnlStep.Controls.Add(this.lblLanguage);
            this.pnlStep.Controls.Add(this.lblUser);
            this.pnlStep.Controls.Add(this.lblProgram);
            this.pnlStep.Controls.Add(this.lblSystem);
            this.pnlStep.Controls.Add(this.lblConnection);
            this.pnlStep.Name = "pnlStep";
            this.pnlStep.Size = new System.Drawing.Size(416, 280);
            // 
            // lblConnection
            // 
            this.lblConnection.Location = new System.Drawing.Point(16, 16);
            this.lblConnection.Name = "lblConnection";
            this.lblConnection.Size = new System.Drawing.Size(72, 24);
            this.lblConnection.TabIndex = 2;
            this.lblConnection.Text = "Connection";
            // 
            // txtConnection
            // 
            this.txtConnection.Location = new System.Drawing.Point(88, 16);
            this.txtConnection.Name = "txtConnection";
            this.txtConnection.Size = new System.Drawing.Size(248, 20);
            this.txtConnection.TabIndex = 1;
            this.txtConnection.Text = "";
            this.txtConnection.TextChanged += new System.EventHandler(this.OnConnectionParamChanged);
            // 
            // txtSystem
            // 
            this.txtSystem.Location = new System.Drawing.Point(88, 48);
            this.txtSystem.Name = "txtSystem";
            this.txtSystem.Size = new System.Drawing.Size(248, 20);
            this.txtSystem.TabIndex = 3;
            this.txtSystem.Text = "";
            this.txtSystem.TextChanged += new System.EventHandler(this.OnConnectionParamChanged);
            // 
            // lblSystem
            // 
            this.lblSystem.Location = new System.Drawing.Point(16, 48);
            this.lblSystem.Name = "lblSystem";
            this.lblSystem.Size = new System.Drawing.Size(72, 24);
            this.lblSystem.TabIndex = 4;
            this.lblSystem.Text = "System";
            // 
            // txtProgram
            // 
            this.txtProgram.Location = new System.Drawing.Point(88, 80);
            this.txtProgram.Name = "txtProgram";
            this.txtProgram.Size = new System.Drawing.Size(248, 20);
            this.txtProgram.TabIndex = 4;
            this.txtProgram.Text = "";
            this.txtProgram.TextChanged += new System.EventHandler(this.OnConnectionParamChanged);
            // 
            // lblProgram
            // 
            this.lblProgram.Location = new System.Drawing.Point(16, 80);
            this.lblProgram.Name = "lblProgram";
            this.lblProgram.Size = new System.Drawing.Size(72, 24);
            this.lblProgram.TabIndex = 6;
            this.lblProgram.Text = "Program";
            // 
            // txtUser
            // 
            this.txtUser.Location = new System.Drawing.Point(88, 112);
            this.txtUser.Name = "txtUser";
            this.txtUser.Size = new System.Drawing.Size(248, 20);
            this.txtUser.TabIndex = 5;
            this.txtUser.Text = "";
            this.txtUser.TextChanged += new System.EventHandler(this.OnConnectionParamChanged);
            // 
            // lblUser
            // 
            this.lblUser.Location = new System.Drawing.Point(16, 112);
            this.lblUser.Name = "lblUser";
            this.lblUser.Size = new System.Drawing.Size(72, 24);
            this.lblUser.TabIndex = 8;
            this.lblUser.Text = "User";
            // 
            // lblLanguage
            // 
            this.lblLanguage.Location = new System.Drawing.Point(16, 176);
            this.lblLanguage.Name = "lblLanguage";
            this.lblLanguage.Size = new System.Drawing.Size(72, 24);
            this.lblLanguage.TabIndex = 10;
            this.lblLanguage.Text = "Language";
            // 
            // butConnWizard
            // 
            this.butConnWizard.Location = new System.Drawing.Point(344, 16);
            this.butConnWizard.Name = "butConnWizard";
            this.butConnWizard.Size = new System.Drawing.Size(64, 24);
            this.butConnWizard.TabIndex = 2;
            this.butConnWizard.Text = "Wizard";
            this.butConnWizard.Click += new System.EventHandler(this.OnButConnWizardClick);
            // 
            // txtPassword
            // 
            this.txtPassword.Location = new System.Drawing.Point(88, 144);
            this.txtPassword.Name = "txtPassword";
            this.txtPassword.Size = new System.Drawing.Size(248, 20);
            this.txtPassword.TabIndex = 6;
            this.txtPassword.Text = "";
            // 
            // lblPassword
            // 
            this.lblPassword.Location = new System.Drawing.Point(16, 144);
            this.lblPassword.Name = "lblPassword";
            this.lblPassword.Size = new System.Drawing.Size(72, 24);
            this.lblPassword.TabIndex = 14;
            this.lblPassword.Text = "Password";
            // 
            // cboLanguage
            // 
            this.cboLanguage.Location = new System.Drawing.Point(88, 176);
            this.cboLanguage.Name = "cboLanguage";
            this.cboLanguage.Size = new System.Drawing.Size(248, 21);
            this.cboLanguage.TabIndex = 15;
            this.cboLanguage.SelectedIndexChanged += new System.EventHandler(this.OnConnectionParamChanged);
            // 
            // frmStepRepConnect
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(448, 302);
            this.Name = "frmStepRepConnect";
            this.Text = "frmStepRepConnect";
            this.pnlStep.ResumeLayout(false);
            this.ResumeLayout(false);

        }
		#endregion
    } // Class frmStepRepConnect
} // Namespace