using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using RepPP.Toolkit;

namespace RepPP.VSNetWizard
{
	/// <summary>
	/// Form to display the typed instances name clashes messages
	/// </summary>
	public class frmTypedInstNameClashLog : System.Windows.Forms.Form, TypedInstanceGenBase.ILog {
        private System.Windows.Forms.TextBox    txtLog;
        private System.Windows.Forms.Label      label1;
        private System.Windows.Forms.Button     butOk;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmTypedInstNameClashLog() {
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose(bool bDisposing) {
			if (bDisposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose(bDisposing);
		}

        //******************************************************************
        /// <summary>
        /// MessageText:                    Log message text
        /// </summary>
        //******************************************************************
        public string MessageText {
            get {
                return(txtLog.Text);
            }
            set {
                txtLog.Text = value;
            }
        }

        //******************************************************************
        /// <summary>
        /// LogClashBetweenGrpAndCrdName:   Log a clash between generated class for a class and a group
        /// </summary>
        /// <param name="crd">              Card</param>
        /// <param name="grp">              Group</param>
        /// <param name="strName">          Name in clash</param>
        //******************************************************************
        public void LogClashBetweenGrpAndCrdName(RepPP.Card crd, RepPP.Group grp, string strName) {
            txtLog.Text += "-Class name clash: The class name " + strName + " is used for the typed instance for the card " + crd.Name +
                           " and the typed instance for the group " + grp.Name + ".\r\n";
        }

        //******************************************************************
        /// <summary>
        /// LogClashError:                  Log a clash between a generated property and a base member
        /// </summary>
        /// <param name="strName">          Name in clash</param>
        /// <param name="eBaseMemberType">  Type of the base member</param>
        /// <param name="ePropType">        Type of the property</param>
        //******************************************************************
        public void LogClashError(string strName, TypedInstanceGenBase.ClashObjectType eBaseMemberType, TypedInstanceGenBase.ClashObjectType ePropType) {
            txtLog.Text += "-Class member clash: The member name " + strName + " is used for a " + GetClashObjectTypeName(eBaseMemberType) + 
                           " and a generated " + GetClashObjectTypeName(eBaseMemberType) + " .\r\n";
        }

        //******************************************************************
        /// <summary>
        /// GetClashObjectTypeName:         Get the name of an object type
        /// </summary>
        /// <param name="eObjType">         Object type</param>
        /// <returns>
        /// Name of an object type
        /// </returns>
        //******************************************************************
        private string GetClashObjectTypeName(TypedInstanceGenBase.ClashObjectType eObjType) {
            string strRetVal = String.Empty;

            switch (eObjType) {
                case TypedInstanceGenBase.ClashObjectType.Unknown:
                    strRetVal = "unknown";
                    break;
                case TypedInstanceGenBase.ClashObjectType.BaseField:
                    strRetVal = "base field";
                    break;
                case TypedInstanceGenBase.ClashObjectType.BaseProperty:
                    strRetVal = "base property";
                    break;
                case TypedInstanceGenBase.ClashObjectType.BaseMethod:
                    strRetVal = "base method";
                    break;
                case TypedInstanceGenBase.ClashObjectType.BaseCtor:
                    strRetVal = "base constructor";
                    break;
                case TypedInstanceGenBase.ClashObjectType.BaseEvent:
                    strRetVal = "base event";
                    break;
                case TypedInstanceGenBase.ClashObjectType.Group:
                    strRetVal = "group instance property";
                    break;
                case TypedInstanceGenBase.ClashObjectType.Field:
                    strRetVal = "fiedl property";
                    break;
            }
            return(strRetVal);
        }

        //******************************************************************
        /// <summary>
        /// OnButOkClick:                   Handel the click event on the ok button
        /// </summary>
        /// <param name="sender">           Sender</param>
        /// <param name="e">                Arguments</param>
        //******************************************************************
        private void OnButOkClick(object sender, System.EventArgs e) {
            Close();
        }

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.txtLog = new System.Windows.Forms.TextBox();
            this.label1 = new System.Windows.Forms.Label();
            this.butOk = new System.Windows.Forms.Button();
            this.SuspendLayout();
            // 
            // txtLog
            // 
            this.txtLog.Location = new System.Drawing.Point(16, 56);
            this.txtLog.Multiline = true;
            this.txtLog.Name = "txtLog";
            this.txtLog.ReadOnly = true;
            this.txtLog.ScrollBars = System.Windows.Forms.ScrollBars.Both;
            this.txtLog.Size = new System.Drawing.Size(424, 232);
            this.txtLog.TabIndex = 0;
            this.txtLog.Text = "";
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(16, 16);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(336, 32);
            this.label1.TabIndex = 1;
            this.label1.Text = "Generating the typed instances classes will cause the foillowing name clashes:";
            // 
            // butOk
            // 
            this.butOk.Location = new System.Drawing.Point(190, 300);
            this.butOk.Name = "butOk";
            this.butOk.TabIndex = 2;
            this.butOk.Text = "Ok";
            this.butOk.Click += new System.EventHandler(this.OnButOkClick);
            // 
            // frmTypedInstNameClashLog
            // 
            this.AcceptButton = this.butOk;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(454, 334);
            this.Controls.Add(this.butOk);
            this.Controls.Add(this.label1);
            this.Controls.Add(this.txtLog);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.Fixed3D;
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "frmTypedInstNameClashLog";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Typed Instances Name Clash";
            this.ResumeLayout(false);

        }
		#endregion

	}
}
